HeliQ
=====

Quantification of helical morphologies

* Home: `github.com/wohe157/heliq <https://github.com/wohe157/heliq>`_
* Documentation: `heliq.readthedocs.io <https://heliq.readthedocs.io/>`_
* Authors: Wouter Heyvaert, Sara Bals, Wiebke Albrecht


Installation
------------

From PyPI::

    pip install heliq

From Anaconda::

    conda install plogpro -c wohe
